==> dogtag-pki_10.8.3.orig.tar.xz: pki-10.8.3/tests/dogtag/pytest-ansible/installation/roles/Test_Trigger/files/config_templates/ansible_constants.py <==
#common to all subsystems
MASTER_HOSTNAME = 'pki1.example.com'
CLONE_HOSTNAME = 'pki2.example.com'

CLIENT_PKCS12_PASSWORD = 'SECret.123'
CLIENT_DIR_PASSWORD = 'SECret.123'
BACKUP_PASSWORD = 'SECret.123'
CLIENT_DATABASE_PASSWORD = 'SECret.123'
NSSDB = '/opt/pki/certdb'
#CA Instance
CA_HTTPS_PORT = '20443'
CA_HTTP_PORT = '20080'
CA_AJP_PORT = '20009'
CA_TOMCAT_PORT = '20005'
CA_CLIENT_DIR = '/opt/topology-CA'
CA_INSTANCE_NAME = 'topology-CA'
SECURITY_DOMAIN_PASSWORD = 'SECret.123'
CA_PASSWORD = 'SECret.123'
CA_SECURITY_DOMAIN_NAME = 'topology_Foobarmaster.org'
CA_ADMIN_USERNAME = 'caadmin'
CA_ADMIN_NICK = 'PKI CA Administrator for Example.Org'
#KRA Instance
KRA_INSTANCE_NAME = 'topology-KRA'
KRA_HTTPS_PORT = 21443
KRA_HTTP_PORT = 21080
KRA_AJP_PORT = 21009
KRA_TOMCAT_PORT = 21005
KRA_PASSWORD = 'SECret.123'
KRA_CLIENT_DIR = '/opt/topology-KRA'
KRA_ADMIN_NICK = 'PKI KRA Administrator for Example.Org'
#OCSP Instance
OCSP_INSTANCE_NAME = 'topology-OCSP'
OCSP_HTTPS_PORT = 22443
OCSP_HTTP_PORT = 22080
OCSP_AJP_PORT = 22009
OCSP_TOMCAT_PORT = 22005
OCSP_PASSWORD = 'SECret.123'
OCSP_CLIENT_DIR = '/opt/topology-OCSP'
OCSP_ADMIN_NICK = 'PKI OCSP Administrator for Example.Org'
#TKS Instance
TKS_INSTANCE_NAME = 'topology-TKS'
TKS_HTTPS_PORT = 23443
TKS_HTTP_PORT = 23080
TKS_AJP_PORT = 23009
TKS_TOMCAT_PORT = 23005
TKS_PASSWORD = 'SECret.123'
TKS_CLIENT_DIR = '/opt/topology-TKS'
#TPS instance
TPS_INSTANCE_NAME = 'topology-TPS'
TPS_HTTPS_PORT = '25443'
TPS_HTTP_PORT = '25080'
TPS_AJP_PORT = '25009'
TPS_TOMCAT_PORT = '25005'
TPS_PASSWORD = 'SECret.123'
TPS_CLIENT_DIR = '/opt/topology-TPS'
TPS_ADMIN_NICK = 'PKI TPS Administrator for Example.Org'
#LDAP Details
LDAP_PORT = 'ldapServerPort'
LDAP_BIND_DN = 'cn=Directory Manager'
LDAP_PASSWD = 'SECret.123'
LDAP_BASE_DN = 'dc=example,dc=org'
LDAP_KRA_PORT = 'ldapkraServerPort'
LDAP_OCSP_PORT = 'ldapocspServerPort'
LDAP_TKS_PORT = 'ldaptksServerPort'
LDAP_TPS_PORT = 'ldaptpsServerPort'
LDAP_USER = 'foobar'
LDAP_USER_ENROLL = 'testuser'
CUID = '40906145C76224192D2B'
CUID_01 = '40906145C76224192D11'
TPS_OPERATION = 'ra_enroll'
#Details for tps-activity cli automation
LDAP_USER1 = 'jdoe'
TOKEN_FORMAT = 'ra_format'
TOKEN_RESET_PIN = 'ra_reset_pin'
TOKEN_CUID = '40000000000000000002'

==> dogtag-pki_11.2.1.orig.tar.xz: pki-11.2.1/tests/dogtag/pytest-ansible/installation/roles/Test_Trigger/files/config_templates/ansible_constants.py <==
#common to all subsystems
MASTER_HOSTNAME = 'pki1.example.com'
CLONE_HOSTNAME = 'pki2.example.com'

CLIENT_PKCS12_PASSWORD = 'SECret.123'
CLIENT_DIR_PASSWORD = 'SECret.123'
BACKUP_PASSWORD = 'SECret.123'
CLIENT_DATABASE_PASSWORD = 'SECret.123'
NSSDB = '/opt/pki/certdb'
ROOT_CA_CERT_PATH = '/tmp/rootCA.pem'

#CA Instance
CA_HTTPS_PORT = '20443'
CA_HTTP_PORT = '20080'
CA_AJP_PORT = '20009'
CA_TOMCAT_PORT = '20005'
CA_CLIENT_DIR = '/opt/topology-CA'
CA_INSTANCE_NAME = 'topology-CA'
SECURITY_DOMAIN_PASSWORD = 'SECret.123'
CA_PASSWORD = 'SECret.123'
CA_SECURITY_DOMAIN_NAME = 'topology_Foobarmaster.org'
CA_ADMIN_USERNAME = 'caadmin'
CA_ADMIN_NICK = 'PKI CA Administrator for Example.Org'
#KRA Instance
KRA_INSTANCE_NAME = 'topology-KRA'
KRA_HTTPS_PORT = 21443
KRA_HTTP_PORT = 21080
KRA_AJP_PORT = 21009
KRA_TOMCAT_PORT = 21005
KRA_PASSWORD = 'SECret.123'
KRA_CLIENT_DIR = '/opt/topology-KRA'
KRA_ADMIN_NICK = 'PKI KRA Administrator for Example.Org'
KRA_ADMIN_USERNAME = 'kraadmin'
#OCSP Instance
OCSP_INSTANCE_NAME = 'topology-OCSP'
OCSP_HTTPS_PORT = 22443
OCSP_HTTP_PORT = 22080
OCSP_AJP_PORT = 22009
OCSP_TOMCAT_PORT = 22005
OCSP_PASSWORD = 'SECret.123'
OCSP_CLIENT_DIR = '/opt/topology-OCSP'
OCSP_ADMIN_NICK = 'PKI OCSP Administrator for Example.Org'
OCSP_ADMIN_USERNAME = 'ocspadmin'
#TKS Instance
TKS_INSTANCE_NAME = 'topology-TKS'
TKS_HTTPS_PORT = 23443
TKS_HTTP_PORT = 23080
TKS_AJP_PORT = 23009
TKS_TOMCAT_PORT = 23005
TKS_PASSWORD = 'SECret.123'
TKS_CLIENT_DIR = '/opt/topology-TKS'
TKS_ADMIN_NICK = 'PKI TKS Administrator for Example.Org'
TKS_ADMIN_USERNAME = 'tksadmin'
#TPS instance
TPS_INSTANCE_NAME = 'topology-TPS'
TPS_HTTPS_PORT = '25443'
TPS_HTTP_PORT = '25080'
TPS_AJP_PORT = '25009'
TPS_TOMCAT_PORT = '25005'
TPS_PASSWORD = 'SECret.123'
TPS_CLIENT_DIR = '/opt/topology-TPS'
TPS_ADMIN_NICK = 'PKI TPS Administrator for Example.Org'
TPS_ADMIN_USERNAME = 'tpsadmin'
#LDAP Details
LDAP_PORT = 'ldapServerPort'
LDAPS_PORT = 'ldapSecureServerPort'
LDAP_SECURE_CON_PEM_FILE = 'ldapSecreConPemFile'
LDAP_BIND_DN = 'cn=Directory Manager'
LDAP_PASSWD = 'SECret.123'
LDAP_BASE_DN = 'dc=example,dc=org'
LDAP_KRA_PORT = 'ldapkraServerPort'
LDAP_OCSP_PORT = 'ldapocspServerPort'
LDAP_TKS_PORT = 'ldaptksServerPort'
LDAP_TPS_PORT = 'ldaptpsServerPort'
LDAP_USER = 'foobar'
LDAP_USER_ENROLL = 'testuser'
CUID = '40906145C76224192D2B'
CUID_01 = '40906145C76224192D11'
TPS_OPERATION = 'ra_enroll'
#Details for tps-activity cli automation
LDAP_USER1 = 'jdoe'
TOKEN_FORMAT = 'ra_format'
TOKEN_RESET_PIN = 'ra_reset_pin'
TOKEN_CUID = '40000000000000000002'

#SUBCA Instance
SUBCA_INSTANCE_NAME = 'topology-SubCA'
SUBCA_CA_INSTANCE_NAME = 'topology-SubCA-CA'
SUBCA_KRA_INSTANCE_NAME = 'topology-SubCA-KRA'
SUBCA_ADMIN_NICK = 'PKI Administrator for example.com'
SUBCA_HTTPS_PORT = '18443'
SUBCA_HTTP_PORT = '18080'
SUBCA_AJP_PORT = '18009'
SUBCA_TOMCAT_PORT = '18005'
SUBCA_KRA_HTTPS_PORT = '19443'
SUBCA_KRA_HTTP_PORT = '19080'
SUBCA_KRA_AJP_PORT = '19009'
SUBCA_KRA_TOMCAT_PORT = '19005'
SUBCA_SECURITY_DOMAIN_NAME = 'SUBORDINATE'
